==> MIDITrail-Ver.1.1.3-Windows_src.zip: MIDITrail/MIDITrail/MTHowToViewDlg.cpp <==
//******************************************************************************
//
// MIDITrail / MTHowToViewDlg
//
// @_CAO
//
// Copyright (C) 2010-2012 WADA Masashi. All Rights Reserved.
//
//******************************************************************************

#include "StdAfx.h"
#include "resource.h"
#include "YNBaseLib.h"
#include "MTParam.h"
#include "MTHowToViewDlg.h"

using namespace YNBaseLib;

//******************************************************************************
// p[^`
//******************************************************************************
//\摜
#define MT_HOWTOVIEW_IMAGE_NUM  (3)

//******************************************************************************
// EBhEvV[Wpp[^ݒ
//******************************************************************************
MTHowToViewDlg* MTHowToViewDlg::m_pThis = NULL;

//******************************************************************************
// RXgN^
//******************************************************************************
MTHowToViewDlg::MTHowToViewDlg(void)
{
	m_pThis = this;
	m_hMemBmpPixel = NULL;
	m_pBmpPixcel = NULL;
	m_PageNo = 0;
	m_hWnd = NULL;
}

//******************************************************************************
// fXgN^
//******************************************************************************
MTHowToViewDlg::~MTHowToViewDlg(void)
{
	_Clear();
}

//******************************************************************************
// EBhEvV[W
//******************************************************************************
INT_PTR CALLBACK MTHowToViewDlg::_WndProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
{
	return m_pThis->_WndProcImpl(hWnd, message, wParam, lParam);
}

//******************************************************************************
// EBhEvV[WF
//******************************************************************************
INT_PTR MTHowToViewDlg::_WndProcImpl(
		HWND hDlg,
		UINT message,
		WPARAM wParam,
		LPARAM lParam
	)
{
	int result = 0;
	BOOL bresult = FALSE;

	UNREFERENCED_PARAMETER(lParam);

	switch (message) {
		case WM_INITDIALOG:
			result = _OnInitDlg(hDlg);
			if (result != 0) goto EXIT;
			bresult = TRUE;
			break;
		case WM_COMMAND:
			if (LOWORD(wParam) == IDOK) {
				EndDialog(hDlg, LOWORD(wParam));
				bresult = TRUE;
			}
			else if (LOWORD(wParam) == IDCANCEL) {
				EndDialog(hDlg, LOWORD(wParam));
				bresult = TRUE;
			}
			else if (LOWORD(wParam) == IDC_BTN_PREVIOUS) {
				result = _OnPreviousButton();
				if (result != 0) goto EXIT;
				bresult = TRUE;
			}
			else if (LOWORD(wParam) == IDC_BTN_NEXT) {
				result = _OnNextButton();
				if (result != 0) goto EXIT;
				bresult = TRUE;
			}
			else if (LOWORD(wParam) == IDC_BTN_CLOSE) {
				EndDialog(hDlg, LOWORD(wParam));
				bresult = TRUE;
			}
			break;
		case WM_PAINT:
			result = _DrawHowToBmp();
			if (result != 0) goto EXIT;
			bresult = TRUE;
			break;
	}

EXIT:;
	if (result != 0) {
		YN_SHOW_ERR(hDlg);
	}
	return (INT_PTR)bresult;
}

//******************************************************************************
// \
//******************************************************************************
int MTHowToViewDlg::Show(
		HWND hParentWnd
	)
{
	int result = 0;
	INT_PTR dresult = 0;
	HINSTANCE hInstance = NULL;

	m_PageNo = 0;

	//AvP[VCX^Xnh擾
	hInstance = (HINSTANCE)GetWindowLongPtr(hParentWnd, GWLP_HINSTANCE);
	if (hInstance == NULL) {
		result = YN_SET_ERR("Windows API error.", GetLastError(), (DWORD)hParentWnd);
		goto EXIT;
	}

	//_CAO\
	dresult = DialogBox(
					hInstance,							//CX^Xnh
					MAKEINTRESOURCE(IDD_HOWTOVIEW),		//_CAO{bNXev[g
					hParentWnd,							//eEBhEnh
					_WndProc							//_CAO{bNXvV[W
				);
	if ((dresult == 0) || (dresult == -1)) {
		result = YN_SET_ERR("Windows API error.", GetLastError(), (DWORD)hInstance);
		goto EXIT;
	}

EXIT:;
	return result;
}

//******************************************************************************
// _CAO\O
//******************************************************************************
int MTHowToViewDlg::_OnInitDlg(
		HWND hDlg
	)
{
	int result = 0;

	m_hWnd = hDlg;

	//HowTorbg}bvǂݍ
	result = _LoadHowToBmp();
	if (result != 0) goto EXIT;

	//{^ԍXV
	_UpdateButtonStatus();

EXIT:;
	return result;
}

//******************************************************************************
// HowTorbg}bvǂݍ
//******************************************************************************
int MTHowToViewDlg::_LoadHowToBmp()
{
	int result = 0;
	HANDLE hFile = NULL;
	BOOL bresult = FALSE;
	DWORD numOfBytesRead = 0;
	DWORD fp = 0;
	HANDLE hMemBmpPixel = NULL;
	BYTE* pBmpPixcel = NULL;
	TCHAR bmpFilePath[_MAX_PATH] = {_T('\0')};
	TCHAR* pBmpFileName[3] = { MT_IMGFILE_HOWTOVIEW1, MT_IMGFILE_HOWTOVIEW2, MT_IMGFILE_HOWTOVIEW3 };

	_Clear();

	//----------------------------------------------------------------
	//t@CI[v
	//----------------------------------------------------------------
	//vZXst@CfBNgpX擾
	result = YNPathUtil::GetModuleDirPath(bmpFilePath, _MAX_PATH);
	if (result != 0) goto EXIT;

	if (m_PageNo >= MT_HOWTOVIEW_IMAGE_NUM) {
		result = YN_SET_ERR("Program error.", m_PageNo, 0);
		goto EXIT;
	}

	//BMPt@CpX쐬
	_tcscat_s(bmpFilePath, _MAX_PATH, pBmpFileName[m_PageNo]);

	//BMPt@CJ
	hFile = CreateFile(
				bmpFilePath,			//t@CpX
				GENERIC_READ,			//ANZX^Cv
				0,						//L@
				NULL,					//ZLeB
				OPEN_EXISTING,			//w
				FILE_ATTRIBUTE_NORMAL,	//t@CƃtO
				NULL					//ev[gt@Cnh
			);
	if (hFile == INVALID_HANDLE_VALUE) {
		result = YN_SET_ERR("File open error.", GetLastError(), 0);
		goto EXIT;
	}

	//----------------------------------------------------------------
	//BMPt@Cwb_
	//----------------------------------------------------------------
	//BMPt@Cwb_ǂݍ
	bresult = ReadFile(
					hFile,							//t@Cnh
					(LPBITMAPFILEHEADER)&m_BmpHead,	//obt@ʒu
					sizeof(BITMAPFILEHEADER),		//obt@TCY
					&numOfBytesRead,				//ǂݎTCY
					NULL							//I[o[bv\̃obt@
				);
	if (!bresult) {
		result = YN_SET_ERR("File read error.", GetLastError(), 0);
		goto EXIT;
	}

	//t@C^Cv̊mF "BM"
	if (m_BmpHead.bfType != 0x4D42) {
		result = YN_SET_ERR("Invalid data found.", m_BmpHead.bfType, 0);
		goto EXIT;
	}

	//----------------------------------------------------------------
	//BMPwb_
	//----------------------------------------------------------------
	//BMPwb_ǂݍ
	bresult = ReadFile(
					hFile,							//t@Cnh
					(LPBITMAPINFOHEADER)&m_BmpInfo,	//obt@ʒu
					sizeof(BITMAPINFOHEADER),		//obt@TCY
					&numOfBytesRead,				//ǂݎTCY
					NULL							//I[o[bv\̃obt@
				);
	if (!bresult) {
		result = YN_SET_ERR("File read error.", GetLastError(), 0);
		goto EXIT;
	}

	//24bit摜ȊO͓ǂ݂܂
	if ((m_BmpInfo.biBitCount != 24) || (m_BmpInfo.biClrUsed != 0)) {
		result = YN_SET_ERR("Invalid BMP file.", m_BmpInfo.biBitCount, m_BmpInfo.biClrUsed);
		goto EXIT;
	}

	//----------------------------------------------------------------
	//BMPsNZf[^
	//----------------------------------------------------------------
	//sNZf[^JnʒuɃt@C|C^ݒ
	fp = SetFilePointer(
				hFile,					//t@Cnh
				m_BmpHead.bfOffBits,	//t@C|C^ړoCgF32bit
				0,						//t@C|C^ړoCgF32bit
				FILE_BEGIN				//Jn_
			);
	if (fp == INVALID_SET_FILE_POINTER) {
		result = YN_SET_ERR("File access error.", GetLastError(), m_BmpHead.bfOffBits);
		goto EXIT;
	}

	//sNZf[^ǂݍݗpm
	hMemBmpPixel = GlobalAlloc(GHND, m_BmpHead.bfSize);
	if (hMemBmpPixel == NULL) {
		result = YN_SET_ERR("Could not allocate memory.", 0, 0);
		goto EXIT;
	}
	pBmpPixcel = (BYTE*)GlobalLock(hMemBmpPixel);
	if (pBmpPixcel == NULL) {
		result = YN_SET_ERR("Could not allocate memory.", 0, 0);
		goto EXIT;
	}

	//BMPsNZf[^ǂݍ
	bresult = ReadFile(
					hFile,				//t@Cnh
					pBmpPixcel,			//obt@ʒu
					m_BmpHead.bfSize,	//obt@TCY
					&numOfBytesRead,	//ǂݎTCY
					NULL				//I[o[bv\̃obt@
				);
	if (!bresult) {
		result = YN_SET_ERR("File read error.", GetLastError(), 0);
		goto EXIT;
	}

	m_hMemBmpPixel = hMemBmpPixel;
	m_pBmpPixcel = pBmpPixcel;

EXIT:;
	if (hFile != NULL) {
		CloseHandle(hFile);
	}
	if (result != 0) {
		if (hMemBmpPixel != NULL) {
			GlobalUnlock(hMemBmpPixel);
			GlobalFree(hMemBmpPixel);
		}
	}
	return result;
}

//******************************************************************************
// HowTorbg}bv`
//******************************************************************************
int MTHowToViewDlg::_DrawHowToBmp()
{
	int result = 0;
	int apiresult = 0;
	HDC hdc = NULL;
	HWND hWndPicture = NULL;
	PAINTSTRUCT ps;

	if (m_pBmpPixcel == NULL) goto EXIT;

	//`ΏۃEBhEnh擾
	hWndPicture = GetDlgItem(m_hWnd, IDC_HOWTO_PICTURE);

	//`揀
	hdc = BeginPaint(hWndPicture, &ps);

	apiresult = SetDIBitsToDevice(
					hdc,					//foCXReLXgnh
					0,						//]捶̍WFx
					0,						//]捶̍WFy
					m_BmpInfo.biWidth,		//]TCYF
					m_BmpInfo.biHeight,		//]TCYF
					0,						//]W̍WFx
					0,						//]W̍WFy
					0,						//Jns
					m_BmpInfo.biHeight,		//s
					m_pBmpPixcel,			//rbg}bvf[^JñAhX
					(BITMAPINFO*)&m_BmpInfo,//BMPwb_
					DIB_RGB_COLORS			//Fw
				);
	if (apiresult == 0) {
		result = YN_SET_ERR("Windows API error.", GetLastError(), 0);
		goto EXIT;
	}

	//`I
	EndPaint(hWndPicture, &ps);

EXIT:;
	return result;
}

//******************************************************************************
// NA
//******************************************************************************
void MTHowToViewDlg::_Clear()
{
	ZeroMemory(&m_BmpHead, sizeof(BITMAPFILEHEADER));
	ZeroMemory(&m_BmpInfo, sizeof(BITMAPINFO));

	if (m_hMemBmpPixel != NULL) {
		GlobalUnlock(m_hMemBmpPixel);
		GlobalFree(m_hMemBmpPixel);
		m_hMemBmpPixel = NULL;
	}
	m_pBmpPixcel = NULL;
}

//******************************************************************************
// O{^
//******************************************************************************
int MTHowToViewDlg::_OnPreviousButton()
{
	int result = 0;

	//Ỏ摜ֈړ
	m_PageNo--;

	//Ô߃K[h
	if (m_PageNo < 0) {
		m_PageNo = 0;
	}

	//{^ԍXV
	_UpdateButtonStatus();

	//摜\
	result = _DrawHowToImage();
	if (result != 0) goto EXIT;

EXIT:;
	return result;
}

//******************************************************************************
// {^
//******************************************************************************
int MTHowToViewDlg::_OnNextButton()
{
	int result = 0;

	//̉摜ֈړ
	m_PageNo++;

	//Ô߃K[h
	if (m_PageNo >= MT_HOWTOVIEW_IMAGE_NUM) {
		m_PageNo = MT_HOWTOVIEW_IMAGE_NUM - 1;
	}

	//{^ԍXV
	_UpdateButtonStatus();

	//摜\
	result = _DrawHowToImage();
	if (result != 0) goto EXIT;

EXIT:;
	return result;
}

//******************************************************************************
// 摜\
//******************************************************************************
int MTHowToViewDlg::_DrawHowToImage()
{
	int result = 0;

	//HowTorbg}bvǂݍ
	result = _LoadHowToBmp();
	if (result != 0) goto EXIT;

	//ĕ`
	InvalidateRect(
			m_hWnd,	//EBhEnh
			NULL,	//XV[WwFS
			FALSE	//wiFȂ
		);
	UpdateWindow(m_hWnd);

EXIT:;
	return result;
}

//******************************************************************************
// {^ԍXV
//******************************************************************************
void MTHowToViewDlg::_UpdateButtonStatus()
{
	HWND hPreviousButton = NULL;
	HWND hNextButton = NULL;

	hPreviousButton = GetDlgItem(m_hWnd, IDC_BTN_PREVIOUS);
	hNextButton = GetDlgItem(m_hWnd, IDC_BTN_NEXT);

	EnableWindow(hPreviousButton, TRUE);
	EnableWindow(hNextButton, TRUE);

	//擪摜\FO{^s
	if (m_PageNo == 0) {
		EnableWindow(hPreviousButton, FALSE);
	}
	//ŏI摜\F{^s
	if (m_PageNo == (MT_HOWTOVIEW_IMAGE_NUM - 1)) {
		EnableWindow(hNextButton, FALSE);
	}
}

==> MIDITrail-Ver.1.3.6-Windows_src.zip: MIDITrail/MIDITrail/MTHowToViewDlg.cpp <==
//******************************************************************************
//
// MIDITrail / MTHowToViewDlg
//
// @_CAO
//
// Copyright (C) 2010-2019 WADA Masashi. All Rights Reserved.
//
//******************************************************************************

#include "StdAfx.h"
#include "resource.h"
#include "YNBaseLib.h"
#include "MTParam.h"
#include "MTHowToViewDlg.h"

using namespace YNBaseLib;

//******************************************************************************
// p[^`
//******************************************************************************
//\摜
#define MT_HOWTOVIEW_IMAGE_NUM  (3)

//******************************************************************************
// EBhEvV[Wpp[^ݒ
//******************************************************************************
MTHowToViewDlg* MTHowToViewDlg::m_pThis = NULL;

//******************************************************************************
// RXgN^
//******************************************************************************
MTHowToViewDlg::MTHowToViewDlg(void)
{
	m_pThis = this;
	m_hMemBmpPixel = NULL;
	m_pBmpPixcel = NULL;
	m_PageNo = 0;
	m_hWnd = NULL;
}

//******************************************************************************
// fXgN^
//******************************************************************************
MTHowToViewDlg::~MTHowToViewDlg(void)
{
	_Clear();
}

//******************************************************************************
// EBhEvV[W
//******************************************************************************
INT_PTR CALLBACK MTHowToViewDlg::_WndProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
{
	return m_pThis->_WndProcImpl(hWnd, message, wParam, lParam);
}

//******************************************************************************
// EBhEvV[WF
//******************************************************************************
INT_PTR MTHowToViewDlg::_WndProcImpl(
		HWND hDlg,
		UINT message,
		WPARAM wParam,
		LPARAM lParam
	)
{
	int result = 0;
	BOOL bresult = FALSE;

	UNREFERENCED_PARAMETER(lParam);

	switch (message) {
		case WM_INITDIALOG:
			result = _OnInitDlg(hDlg);
			if (result != 0) goto EXIT;
			bresult = TRUE;
			break;
		case WM_COMMAND:
			if (LOWORD(wParam) == IDOK) {
				EndDialog(hDlg, LOWORD(wParam));
				bresult = TRUE;
			}
			else if (LOWORD(wParam) == IDCANCEL) {
				EndDialog(hDlg, LOWORD(wParam));
				bresult = TRUE;
			}
			else if (LOWORD(wParam) == IDC_BTN_PREVIOUS) {
				result = _OnPreviousButton();
				if (result != 0) goto EXIT;
				bresult = TRUE;
			}
			else if (LOWORD(wParam) == IDC_BTN_NEXT) {
				result = _OnNextButton();
				if (result != 0) goto EXIT;
				bresult = TRUE;
			}
			else if (LOWORD(wParam) == IDC_BTN_CLOSE) {
				EndDialog(hDlg, LOWORD(wParam));
				bresult = TRUE;
			}
			break;
		case WM_PAINT:
			result = _DrawHowToBmp();
			if (result != 0) goto EXIT;
			bresult = TRUE;
			break;
	}

EXIT:;
	if (result != 0) {
		YN_SHOW_ERR(hDlg);
	}
	return (INT_PTR)bresult;
}

//******************************************************************************
// \
//******************************************************************************
int MTHowToViewDlg::Show(
		HWND hParentWnd
	)
{
	int result = 0;
	INT_PTR dresult = 0;
	HINSTANCE hInstance = NULL;

	m_PageNo = 0;

	//AvP[VCX^Xnh擾
	hInstance = (HINSTANCE)(LONG_PTR)GetWindowLongPtr(hParentWnd, GWLP_HINSTANCE);
	if (hInstance == NULL) {
		result = YN_SET_ERR("Windows API error.", GetLastError(), (DWORD64)hParentWnd);
		goto EXIT;
	}

	//_CAO\
	dresult = DialogBox(
					hInstance,							//CX^Xnh
					MAKEINTRESOURCE(IDD_HOWTOVIEW),		//_CAO{bNXev[g
					hParentWnd,							//eEBhEnh
					_WndProc							//_CAO{bNXvV[W
				);
	if ((dresult == 0) || (dresult == -1)) {
		result = YN_SET_ERR("Windows API error.", GetLastError(), (DWORD64)hInstance);
		goto EXIT;
	}

EXIT:;
	return result;
}

//******************************************************************************
// _CAO\O
//******************************************************************************
int MTHowToViewDlg::_OnInitDlg(
		HWND hDlg
	)
{
	int result = 0;

	m_hWnd = hDlg;

	//HowTorbg}bvǂݍ
	result = _LoadHowToBmp();
	if (result != 0) goto EXIT;

	//{^ԍXV
	_UpdateButtonStatus();

EXIT:;
	return result;
}

//******************************************************************************
// HowTorbg}bvǂݍ
//******************************************************************************
int MTHowToViewDlg::_LoadHowToBmp()
{
	int result = 0;
	HANDLE hFile = NULL;
	BOOL bresult = FALSE;
	DWORD numOfBytesRead = 0;
	DWORD fp = 0;
	HANDLE hMemBmpPixel = NULL;
	BYTE* pBmpPixcel = NULL;
	TCHAR bmpFilePath[_MAX_PATH] = {_T('\0')};
	TCHAR* pBmpFileName[3] = { MT_IMGFILE_HOWTOVIEW1, MT_IMGFILE_HOWTOVIEW2, MT_IMGFILE_HOWTOVIEW3 };
	DWORD bmpPixelDataSize = 0;

	_Clear();

	//----------------------------------------------------------------
	//t@CI[v
	//----------------------------------------------------------------
	//vZXst@CfBNgpX擾
	result = YNPathUtil::GetModuleDirPath(bmpFilePath, _MAX_PATH);
	if (result != 0) goto EXIT;

	if (m_PageNo >= MT_HOWTOVIEW_IMAGE_NUM) {
		result = YN_SET_ERR("Program error.", m_PageNo, 0);
		goto EXIT;
	}

	//BMPt@CpX쐬
	_tcscat_s(bmpFilePath, _MAX_PATH, pBmpFileName[m_PageNo]);

	//BMPt@CJ
	hFile = CreateFile(
				bmpFilePath,			//t@CpX
				GENERIC_READ,			//ANZX^Cv
				0,						//L@
				NULL,					//ZLeB
				OPEN_EXISTING,			//w
				FILE_ATTRIBUTE_NORMAL,	//t@CƃtO
				NULL					//ev[gt@Cnh
			);
	if (hFile == INVALID_HANDLE_VALUE) {
		result = YN_SET_ERR("File open error.", GetLastError(), 0);
		goto EXIT;
	}

	//----------------------------------------------------------------
	//BMPt@Cwb_
	//----------------------------------------------------------------
	//BMPt@Cwb_ǂݍ
	bresult = ReadFile(
					hFile,							//t@Cnh
					&m_BmpHead,						//obt@ʒu
					sizeof(BITMAPFILEHEADER),		//ǂݎTCY
					&numOfBytesRead,				//ǂݎTCY
					NULL							//I[o[bv\̃obt@
				);
	if (!bresult) {
		result = YN_SET_ERR("File read error.", GetLastError(), 0);
		goto EXIT;
	}

	//t@C^Cv̊mF "BM"
	if (m_BmpHead.bfType != 0x4D42) {
		result = YN_SET_ERR("Invalid data found.", m_BmpHead.bfType, 0);
		goto EXIT;
	}

	//----------------------------------------------------------------
	//BMPwb_
	//----------------------------------------------------------------
	//BMPwb_ǂݍ
	bresult = ReadFile(
					hFile,							//t@Cnh
					&m_BmpInfo,						//obt@ʒu
					sizeof(BITMAPINFOHEADER),		//ǂݎTCY
					&numOfBytesRead,				//ǂݎTCY
					NULL							//I[o[bv\̃obt@
				);
	if (!bresult) {
		result = YN_SET_ERR("File read error.", GetLastError(), 0);
		goto EXIT;
	}

	//24bit摜ȊO͓ǂ݂܂
	//J[e[u݂ȂƂOƂ
	if ((m_BmpInfo.biBitCount != 24) || (m_BmpInfo.biClrUsed != 0)) {
		result = YN_SET_ERR("Invalid BMP file.", m_BmpInfo.biBitCount, m_BmpInfo.biClrUsed);
		goto EXIT;
	}

	//----------------------------------------------------------------
	//BMPsNZf[^
	//----------------------------------------------------------------
	//sNZf[^JnʒuɃt@C|C^ݒ
	fp = SetFilePointer(
				hFile,					//t@Cnh
				m_BmpHead.bfOffBits,	//t@C|C^ړoCgF32bit
				0,						//t@C|C^ړoCgF32bit
				FILE_BEGIN				//Jn_
			);
	if (fp == INVALID_SET_FILE_POINTER) {
		result = YN_SET_ERR("File access error.", GetLastError(), m_BmpHead.bfOffBits);
		goto EXIT;
	}

	//BMPsNZf[^TCY
	//J[e[u݂ȂƂOƂ
	bmpPixelDataSize = m_BmpHead.bfSize - sizeof(BITMAPFILEHEADER) - sizeof(BITMAPINFOHEADER);

	//sNZf[^ǂݍݗpm
	hMemBmpPixel = GlobalAlloc(GHND, bmpPixelDataSize);
	if (hMemBmpPixel == NULL) {
		result = YN_SET_ERR("Could not allocate memory.", 0, 0);
		goto EXIT;
	}
	pBmpPixcel = (BYTE*)GlobalLock(hMemBmpPixel);
	if (pBmpPixcel == NULL) {
		result = YN_SET_ERR("Could not allocate memory.", 0, 0);
		goto EXIT;
	}

	//BMPsNZf[^ǂݍ
	bresult = ReadFile(
					hFile,				//t@Cnh
					pBmpPixcel,			//obt@ʒu
					bmpPixelDataSize,	//ǂݎTCY
					&numOfBytesRead,	//ǂݎTCY
					NULL				//I[o[bv\̃obt@
				);
	if (!bresult) {
		result = YN_SET_ERR("File read error.", GetLastError(), 0);
		goto EXIT;
	}

	m_hMemBmpPixel = hMemBmpPixel;
	m_pBmpPixcel = pBmpPixcel;

EXIT:;
	if (hFile != NULL) {
		CloseHandle(hFile);
	}
	if (result != 0) {
		if (hMemBmpPixel != NULL) {
			GlobalUnlock(hMemBmpPixel);
			GlobalFree(hMemBmpPixel);
		}
	}
	return result;
}

//******************************************************************************
// HowTorbg}bv`
//******************************************************************************
int MTHowToViewDlg::_DrawHowToBmp()
{
	int result = 0;
	int apiresult = 0;
	HDC hdc = NULL;
	HWND hWndPicture = NULL;
	PAINTSTRUCT ps;

	if (m_pBmpPixcel == NULL) goto EXIT;

	//`ΏۃEBhEnh擾
	hWndPicture = GetDlgItem(m_hWnd, IDC_HOWTO_PICTURE);

	//`揀
	hdc = BeginPaint(hWndPicture, &ps);

	apiresult = SetDIBitsToDevice(
					hdc,					//foCXReLXgnh
					0,						//]捶̍WFx
					0,						//]捶̍WFy
					m_BmpInfo.biWidth,		//]TCYF
					m_BmpInfo.biHeight,		//]TCYF
					0,						//]W̍WFx
					0,						//]W̍WFy
					0,						//Jns
					m_BmpInfo.biHeight,		//s
					m_pBmpPixcel,			//rbg}bvf[^JñAhX
					(BITMAPINFO*)&m_BmpInfo,//BMPwb_
					DIB_RGB_COLORS			//Fw
				);
	if (apiresult == 0) {
		result = YN_SET_ERR("Windows API error.", GetLastError(), 0);
		goto EXIT;
	}

	//`I
	EndPaint(hWndPicture, &ps);

EXIT:;
	return result;
}

//******************************************************************************
// NA
//******************************************************************************
void MTHowToViewDlg::_Clear()
{
	ZeroMemory(&m_BmpHead, sizeof(BITMAPFILEHEADER));
	ZeroMemory(&m_BmpInfo, sizeof(BITMAPINFOHEADER));

	if (m_hMemBmpPixel != NULL) {
		GlobalUnlock(m_hMemBmpPixel);
		GlobalFree(m_hMemBmpPixel);
		m_hMemBmpPixel = NULL;
	}
	m_pBmpPixcel = NULL;
}

//******************************************************************************
// O{^
//******************************************************************************
int MTHowToViewDlg::_OnPreviousButton()
{
	int result = 0;

	//Ỏ摜ֈړ
	m_PageNo--;

	//Ô߃K[h
	if (m_PageNo < 0) {
		m_PageNo = 0;
	}

	//{^ԍXV
	_UpdateButtonStatus();

	//摜\
	result = _DrawHowToImage();
	if (result != 0) goto EXIT;

EXIT:;
	return result;
}

//******************************************************************************
// {^
//******************************************************************************
int MTHowToViewDlg::_OnNextButton()
{
	int result = 0;

	//̉摜ֈړ
	m_PageNo++;

	//Ô߃K[h
	if (m_PageNo >= MT_HOWTOVIEW_IMAGE_NUM) {
		m_PageNo = MT_HOWTOVIEW_IMAGE_NUM - 1;
	}

	//{^ԍXV
	_UpdateButtonStatus();

	//摜\
	result = _DrawHowToImage();
	if (result != 0) goto EXIT;

EXIT:;
	return result;
}

//******************************************************************************
// 摜\
//******************************************************************************
int MTHowToViewDlg::_DrawHowToImage()
{
	int result = 0;

	//HowTorbg}bvǂݍ
	result = _LoadHowToBmp();
	if (result != 0) goto EXIT;

	//ĕ`
	InvalidateRect(
			m_hWnd,	//EBhEnh
			NULL,	//XV[WwFS
			FALSE	//wiFȂ
		);
	UpdateWindow(m_hWnd);

EXIT:;
	return result;
}

//******************************************************************************
// {^ԍXV
//******************************************************************************
void MTHowToViewDlg::_UpdateButtonStatus()
{
	HWND hPreviousButton = NULL;
	HWND hNextButton = NULL;

	hPreviousButton = GetDlgItem(m_hWnd, IDC_BTN_PREVIOUS);
	hNextButton = GetDlgItem(m_hWnd, IDC_BTN_NEXT);

	EnableWindow(hPreviousButton, TRUE);
	EnableWindow(hNextButton, TRUE);

	//擪摜\FO{^s
	if (m_PageNo == 0) {
		EnableWindow(hPreviousButton, FALSE);
	}
	//ŏI摜\F{^s
	if (m_PageNo == (MT_HOWTOVIEW_IMAGE_NUM - 1)) {
		EnableWindow(hNextButton, FALSE);
	}
}
